@@ -48,7 +48,7 @@ var p,o;if(g==="[object Array]"){g=e.length;for(o=[];g--;)o[g]=Ext.clone(e[g])}e
 configureItem:function(e){var g=this.container,p=g.getLayoutTarget();a.apply(this,arguments);e.on("show",function(o){o.xtbHidden!==true&&this.onLayout(g,p)},this);e.on("hide",function(o){o.xtbHidden!==true&&this.onLayout(g,p)},this)},hideItem:function(e){var g=this;c.apply(this,arguments);e.xtbOrigShow=e.show;e.show=function(){e.xtbOrigShow(true);e.xtbWidth=e.getPositionEl().dom.parentNode.offsetWidth;e.xtbOrigHide(false)};e.xtbOrigHide=e.hide;e.hide=function(){g.unhideItem(e);e.hide()}},unhideItem:function(e){e.show=
 e.xtbOrigShow;delete e.xtbOrigShow;e.hide=e.xtbOrigHide;delete e.xtbOrigHide;delete e.xtbWidth;b.apply(this,arguments)},addComponentToMenu:function(e,g){if(g.xtbHidden===true||g.hidden!==true)i.apply(this,arguments)}})})();(function(){var a=Ext.layout.boxOverflow.Menu.prototype.addComponentToMenu;Ext.override(Ext.layout.boxOverflow.Menu,{addComponentToMenu:function(c,b){if(b.xtbHidden===true||b.hidden!==true)a.apply(this,arguments)}})})();
 (function(){Ext.apply(Ext.state.Manager,{components:new Ext.util.MixedCollection(false,function(a){return a.getStateId()}),register:function(a){this.components.add(a)},unregister:function(a){this.components.remove(a)},getComponent:function(a){return this.components.get(a)}})})();
-(function(){var a=Ext.tree.TreeEditor.prototype.bindScroll,c=Ext.tree.TreeEditor.prototype.fitToTree;Ext.override(Ext.tree.TreeEditor,{fitToTree:function(){this.tree&&this.tree.isDestroyed!==true&&c.apply(this,arguments)},bindScroll:function(){this.tree&&this.tree.isDestroyed!==true&&a.apply(this,arguments)}})})();(function(){Ext.override(Ext.tree.TreeSorter,{doSort:function(a){a.childNodes&&a.sort(this.sortFn)}})})();
+(function(){var a=Ext.tree.TreeEditor.prototype.bindScroll,c=Ext.tree.TreeEditor.prototype.fitToTree;Ext.override(Ext.tree.TreeEditor,{fitToTree:function(){this.tree&&this.tree.isDestroyed!==true&&c.apply(this,arguments)},bindScroll:function(){this.tree&&this.tree.isDestroyed!==true&&a.apply(this,arguments)}})})();(function(){Ext.override(Ext.tree.TreeSorter,{doSort:function(a){if(a.childNodes){var c=document.activeElement;a.sort(this.sortFn);c&&c.focus()}}})})();
 (function(){Ext.apply(Ext.util.Format,{fileSize:function(a){Ext.isNumber(a)||(a=0);if(a<1024)return String.format(ngettext("{0} byte","{0} bytes",a),a);a=parseFloat((a/1024).toFixed(1));if(a<1024)return String.format(ngettext("{0} KB","{0} KB",a),a);a=parseFloat((a/1024).toFixed(1));if(a<1024)return String.format(ngettext("{0} MB","{0} MB",a),a);a=parseFloat((a/1024).toFixed(1));if(a<1024)return String.format(ngettext("{0} GB","{0} GB",a),a);a=parseFloat((a/1024).toFixed(1));return String.format(ngettext("{0} TB",
 "{0} TB",a),a)},percentage:function(a,c){Ext.isDefined(c)||(c=2);return(a*100).toFixed(c)+"%"},duration:function(a,c){c=Ext.isDefined(c)?c:0;if(a<60)return String.format(ngettext("{0} minute","{0} minutes",a),a);a=parseFloat((a/60).toFixed(c));if(a<24)return String.format(ngettext("{0} hour","{0} hours",a),a);a=parseFloat((a/24).toFixed(c));if(a<7)return String.format(ngettext("{0} day","{0} days",a),a);a=parseFloat((a/7).toFixed(c));return String.format(ngettext("{0} week","{0} weeks",a),a)},indent:function(a,
 c){for(var b=(Ext.isDefined(a)?a:1)*(Ext.isDefined(c)?c:4),d="",i=0;i<b;i++)d+="&nbsp;";return d},elide:function(a,c,b){c=c||0;b=Ext.isDefined(b)?b:c;if(c===0&&b===0)return a;if(a&&a.length>c+b)return a.substr(0,c)+"..."+a.substr(a.length-b);return a},htmlEncodeUndef:function(){return this.htmlEncode(this.undef.apply(this,arguments))},htmlEncodeDefaultValue:function(){return this.htmlEncode(this.defaultValue.apply(this,arguments))},htmlEncodeElide:function(){return this.htmlEncode(this.elide.apply(this,
