@@ -1,8 +1,8 @@
 /**
  * Clipboard.js
  *
- * Copyright, Moxiecode Systems AB
  * Released under LGPL License.
+ * Copyright (c) 1999-2015 Ephox Corp. All rights reserved
  *
  * License: http://www.tinymce.com/license
  * Contributing: http://www.tinymce.com/contributing
@@ -65,7 +65,7 @@ define("tinymce/pasteplugin/Clipboard", [
 				}
 
 				if (!args.isDefaultPrevented()) {
-					editor.insertContent(html, {merge: editor.settings.paste_merge_formats !== false});
+					editor.insertContent(html, {merge: editor.settings.paste_merge_formats !== false, data: {paste: true}});
 				}
 			}
 		}
@@ -279,6 +279,56 @@ define("tinymce/pasteplugin/Clipboard", [
 			return html;
 		}
 
+		/**
+		 * Some Windows 10/Edge versions will return a double encoded string. This checks if the
+		 * content has this odd encoding and decodes it.
+		 */
+		function decodeEdgeData(data) {
+			var i, out, fingerprint, code;
+
+			// Check if data is encoded
+			fingerprint = [25942, 29554, 28521, 14958];
+			for (i = 0; i < fingerprint.length; i++) {
+				if (data.charCodeAt(i) != fingerprint[i]) {
+					return data;
+				}
+			}
+
+			// Decode UTF-16 to UTF-8
+			out = '';
+			for (i = 0; i < data.length; i++) {
+				code = data.charCodeAt(i);
+
+				/*eslint no-bitwise:0*/
+				out += String.fromCharCode((code & 0x00FF));
+				out += String.fromCharCode((code & 0xFF00) >> 8);
+			}
+
+			// Decode UTF-8
+			return decodeURIComponent(escape(out));
+		}
+
+		/**
+		 * Extracts HTML contents from within a fragment.
+		 */
+		function extractFragment(data) {
+			var idx, startFragment, endFragment;
+
+			startFragment = '<!--StartFragment-->';
+			idx = data.indexOf(startFragment);
+			if (idx !== -1) {
+				data = data.substr(idx + startFragment.length);
+			}
+
+			endFragment = '<!--EndFragment-->';
+			idx = data.indexOf(endFragment);
+			if (idx !== -1) {
+				data = data.substr(0, idx);
+			}
+
+			return data;
+		}
+
 		/**
 		 * Gets various content types out of a datatransfer object.
 		 *
@@ -286,7 +336,7 @@ define("tinymce/pasteplugin/Clipboard", [
 		 * @return {Object} Object with mime types and data for those mime types.
 		 */
 		function getDataTransferItems(dataTransfer) {
-			var data = {};
+			var items = {};
 
 			if (dataTransfer) {
 				// Use old WebKit/IE API
@@ -294,20 +344,26 @@ define("tinymce/pasteplugin/Clipboard", [
 					var legacyText = dataTransfer.getData('Text');
 					if (legacyText && legacyText.length > 0) {
 						if (legacyText.indexOf(mceInternalUrlPrefix) == -1) {
-							data['text/plain'] = legacyText;
+							items['text/plain'] = legacyText;
 						}
 					}
 				}
 
 				if (dataTransfer.types) {
 					for (var i = 0; i < dataTransfer.types.length; i++) {
-						var contentType = dataTransfer.types[i];
-						data[contentType] = dataTransfer.getData(contentType);
+						var contentType = dataTransfer.types[i],
+							data = dataTransfer.getData(contentType);
+
+						if (contentType == 'text/html') {
+							data = extractFragment(decodeEdgeData(data));
+						}
+
+						items[contentType] = data;
 					}
 				}
 			}
 
-			return data;
+			return items;
 		}
 
 		/**
@@ -589,19 +645,40 @@ define("tinymce/pasteplugin/Clipboard", [
 
 			// Remove all data images from paste for example from Gecko
 			// except internal images like video elements
-			editor.parser.addNodeFilter('img', function(nodes) {
-				if (!editor.settings.paste_data_images) {
+			editor.parser.addNodeFilter('img', function(nodes, name, args) {
+				function isPasteInsert(args) {
+					return args.data && args.data.paste === true;
+				}
+
+				function remove(node) {
+					if (!node.attr('data-mce-object') && src !== Env.transparentSrc) {
+						node.remove();
+					}
+				}
+
+				function isWebKitFakeUrl(src) {
+					return src.indexOf("webkit-fake-url") === 0;
+				}
+
+				function isDataUri(src) {
+					return src.indexOf("data:") === 0;
+				}
+
+				if (!editor.settings.paste_data_images && isPasteInsert(args)) {
 					var i = nodes.length;
 
 					while (i--) {
 						var src = nodes[i].attributes.map.src;
 
-						// Some browsers automatically produce data uris on paste
+						if (!src) {
+							continue;
+						}
+
 						// Safari on Mac produces webkit-fake-url see: https://bugs.webkit.org/show_bug.cgi?id=49141
-						if (src && /^(data:image|webkit\-fake\-url)/.test(src)) {
-							if (!nodes[i].attr('data-mce-object') && src !== Env.transparentSrc) {
-								nodes[i].remove();
-							}
+						if (isWebKitFakeUrl(src)) {
+							remove(nodes[i]);
+						} else if (!editor.settings.allow_html_data_urls && isDataUri(src)) {
+							remove(nodes[i]);
 						}
 					}
 				}
