@@ -21,7 +21,7 @@
 		}
 
 		if ( !isset($favicon) || $favicon === false) {
-			$favicon = 'client/resources/design2015/images/favicon.ico?v2.2.0';
+			$favicon = 'client/resources/images/favicon.ico?v2.2.0';
 		}
 
 		return $favicon;
