@@ -301,10 +301,13 @@
 				switch($actionType)
 				{
 					case "open":
-						if($e->getCode() == MAPI_E_NO_ACCESS)
+						if($e->getCode() == MAPI_E_NO_ACCESS) {
 							$e->setDisplayMessage(_("You have insufficient privileges to open this message."));
-						else
+						} elseif($e->getCode() == MAPI_E_NOT_FOUND) {
+							$e->setDisplayMessage(_("Could not find message, either it has been moved or deleted or you don't have access to open this message."));
+						} else {
 							$e->setDisplayMessage(_("Could not open message."));
+						}
 						break;
 
 					case "save":
@@ -350,7 +353,7 @@
 						}
 
 						if(empty($e->displayMessage)) {
-							$e->setDisplayMessage(_("You have insufficient privileges to save items in this folder") . ".");
+							$e->setDisplayMessage(_("You have insufficient privileges to delete items in this folder") . ".");
 						}
 						break;
 
